package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: May 28, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
Key string `json:"key"`
AppId string `json:"appid"`
Secret string `json:"secret"`
Version string `json:"version"`
ComponentAppid string `json:"component_appid"`
ComponentToken string `json:"component_token"`
Cache cachego.Cache `json:"cache"`
}
type GetComponentAccessToken func() string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.